==> walkers-fabric-1.20.1-4.2-sources.jar: tocraft/walkers/mixin/LivingEntityFoodMixin.java <==
package tocraft.walkers.mixin;

import com.google.common.base.Suppliers;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import org.spongepowered.asm.mixin.injection.callback.LocalCapture;
import tocraft.walkers.api.PlayerShape;

import java.util.Arrays;
import java.util.List;
import java.util.function.Supplier;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1493;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_4174;
import net.minecraft.class_4176;

@Mixin(class_1309.class)
public abstract class LivingEntityFoodMixin extends class_1297 {

    @Unique
    private static final Supplier<List<class_4174>> WOLVES_IGNORE = Suppliers.memoize(() -> Arrays.asList(class_4176.field_18645, class_4176.field_18628, class_4176.field_18632));

    public LivingEntityFoodMixin(class_1299<?> type, class_1937 world) {
        super(type, world);
    }

    @Inject(
            method = "addEatEffect",
            at = @At(value = "INVOKE", target = "Ljava/util/Iterator;hasNext()Z"), locals = LocalCapture.CAPTURE_FAILHARD, cancellable = true)
    private void removeFleshHungerForWolves(class_1799 stack, class_1937 level, class_1309 targetEntity, CallbackInfo ci, class_1792 item) {
        if ((class_1309) (Object) this instanceof class_1657 player) {
            class_1309 shape = PlayerShape.getCurrentShape(player);

            // If this player is a Wolf and the item they are eating is an item wolves are immune to, cancel the method.
            if (shape instanceof class_1493) {
                if (WOLVES_IGNORE.get().contains(item.method_19264())) {
                    ci.cancel();
                }
            }
        }
    }
}

==> walkers-fabric-1.20.2-4.4.1-sources.jar: tocraft/walkers/mixin/LivingEntityFoodMixin.java <==
package tocraft.walkers.mixin;

import com.google.common.base.Suppliers;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import org.spongepowered.asm.mixin.injection.callback.LocalCapture;
import tocraft.walkers.api.PlayerShape;

import java.util.Arrays;
import java.util.List;
import java.util.function.Supplier;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1493;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_4174;
import net.minecraft.class_4176;

@Mixin(class_1309.class)
public abstract class LivingEntityFoodMixin extends class_1297 {

    @Unique
    private static final Supplier<List<class_4174>> WOLVES_IGNORE = Suppliers.memoize(() -> Arrays.asList(class_4176.field_18645, class_4176.field_18628, class_4176.field_18632));

    public LivingEntityFoodMixin(class_1299<?> type, class_1937 world) {
        super(type, world);
    }

    @Inject(
            method = "addEatEffect",
            at = @At(value = "HEAD"), locals = LocalCapture.CAPTURE_FAILHARD, cancellable = true)
    private void removeFleshHungerForWolves(class_1799 food, class_1937 level, class_1309 livingEntity, CallbackInfo ci) {
        if ((class_1309) (Object) this instanceof class_1657 player) {
            class_1309 shape = PlayerShape.getCurrentShape(player);

            // If this player is a Wolf and the item they are eating is an item wolves are immune to, cancel the method.
            if (shape instanceof class_1493) {
                if (WOLVES_IGNORE.get().contains(food.method_7909().method_19264())) {
                    ci.cancel();
                }
            }
        }
    }
}
